@@ -19,6 +19,7 @@
 #' @param assign.short.name = TRUE.  If TRUE, short names from find.short.lipid.name and/or find.short.synonym = TRUE, short names are assigned the be the default annotation name ($ann slot), and original annotations are moved to $long.name slot.
 #' @param all.props logical.  If TRUE, all pubchem properties (https://pubchemdocs.ncbi.nlm.nih.gov/pug-rest$_Toc494865567) are returned.  If false, only a subset (faster).
 #' @param get.bioassays logical. If TRUE, return a table summarizing existing bioassay data for that CID. 
+#' @param get.pathways logical.  If TRUE, return a table of metabolic pathways for that CID.
 #' @param write.csv logical.  If TRUE, write csv files of all returned pubchem data. 
 #' @param search.name character.  optional name to assign to pubchem search to name output .csv files.   
 #' @return returns a list with one or more of $pubchem (compound name and identifiers) - one row in dataframe per CID; $properties contains physicochemical properties - one row in dataframe per CID; $vendors contains the number of vendors for a given compound and selects a vendor based on 'priority.vendors' supplied, or randomly choses a vendor with a HTML link - one row in dataframe per CID;  $bioassays contains a summary of bioassay activity data from pubchem - zero to many rows in dataframe per CID
@@ -28,27 +29,28 @@
 #' 
 
 rc.cmpd.get.pubchem <- function(
-  ramclustObj = NULL,
-  search.name = NULL,
-  cmpd.names = NULL,
-  cmpd.cid = NULL,
-  cmpd.inchikey = NULL,
-  cmpd.smiles = NULL,
-  use.parent.cid = FALSE,
-  manual.entry = FALSE,
-  get.vendors = FALSE,
-  priority.vendors = c("Sigma Aldrich", "Alfa Chemistry", "Acros Organics", "VWR", 
-                       "Alfa Aesar", "molport", "Key Organics", "BLD Pharm"),
-  get.properties = TRUE,
-  all.props = FALSE,
-  get.synonyms = TRUE,
-  find.short.lipid.name = TRUE,
-  find.short.synonym = TRUE,
-  max.name.length = 30,
-  assign.short.name = TRUE,
-  get.bioassays = FALSE,
-  write.csv = TRUE
-  
+    ramclustObj = NULL,
+    search.name = NULL,
+    cmpd.names = NULL,
+    cmpd.cid = NULL,
+    cmpd.inchikey = NULL,
+    cmpd.smiles = NULL,
+    use.parent.cid = FALSE,
+    manual.entry = FALSE,
+    get.vendors = FALSE,
+    priority.vendors = c("Sigma Aldrich", "Alfa Chemistry", "Acros Organics", "VWR", 
+                         "Alfa Aesar", "molport", "Key Organics", "BLD Pharm"),
+    get.properties = TRUE,
+    all.props = FALSE,
+    get.synonyms = TRUE,
+    find.short.lipid.name = TRUE,
+    find.short.synonym = TRUE,
+    max.name.length = 30,
+    assign.short.name = TRUE,
+    get.bioassays = TRUE,
+    get.pathways = TRUE,
+    write.csv = TRUE
+    
 ) {
   
   ## function to close failed pubchem queries to prevent 
@@ -184,6 +186,8 @@ rc.cmpd.get.pubchem <- function(
       }
     }
     
+  } else {
+    html.smiles <- cmpd.smiles
   }
   
   
@@ -247,7 +251,7 @@ rc.cmpd.get.pubchem <- function(
           as.integer(as.character(readLines(html)))
         },
         error=function(cond) {
-          
+          closePubchemConnections()
           stop("pubchem rest connection could not be established. This may be due to:", '\n',
                "  -  lack of internet access", '\n',
                "  -  pubchem server is down", '\n',
@@ -255,9 +259,11 @@ rc.cmpd.get.pubchem <- function(
                '\n')
         },
         warning=function(x) {
+          closePubchemConnections()
           NA
         },
         finally={
+          closePubchemConnections()
           cons <- suppressWarnings(showConnections(all = TRUE)); rm(cons)
         }
         
@@ -750,6 +756,20 @@ rc.cmpd.get.pubchem <- function(
     }
   }
   
+  if(get.pathways) {
+    cat("getting pathway from cid", '\n')
+
+    for(i in 1:length(cid)) {
+      pathway <- get.pathways(cid = cid[i])
+      pathway <- cbind("cid" = rep(cid[i]), pathway)
+      if(!any(ls()=="pathways")) pathways <- pathway[0,]
+      if(is.na(pathway[1,'name'])) next
+      pathways <- rbind(pathways, pathway)
+      
+    }
+    pubchem$pathways <- pathways
+  }
+  
   for(i in 1:length(pubchem)) {
     if(!is.data.frame(pubchem[[i]])) next
     if(nrow(pubchem[[i]]) == length(ramclustObj$cmpd)) {
